@@ -14,6 +14,7 @@ import logging
 import traceback
 
 import os
+from datetime import datetime as dt
 
 from optparse import OptionParser
 
@@ -35,8 +36,6 @@ class ldmStorageFolder(ldmStorage):
         ldmStorage.__init__(self,iModeRev=iModeRev,
                             sLogger=sLogger,iLv=iLv,
                             iVerbose=iVerbose)
-        #self.__initDat__()
-        #self.__initCfg__()
     def __initCfg__(self):
         """initialize configuration properties
         """
@@ -48,6 +47,11 @@ class ldmStorageFolder(ldmStorage):
             # ----- end:initialize
             # +++++ beg:default configuration
             self.dCfgDft['lSkipDN']=['CVS','.git']
+            self.dCfgDft['sTimePrecision']='seconds'
+            self.dCfgDft['sStatNew']='zNew'
+            self.dCfgDft['sStatUse']='zUse'
+            self.dCfgDft['sStatMod']='zMod'
+            #self.dCfgDft['zPrecision']='minutes'
             # ----- end:default configuration
             self.logDbg('end:%s',sOrg)
             return 1
@@ -242,6 +246,12 @@ class ldmStorageFolder(ldmStorage):
             if self.iVerbose>0:
                 self.logDbg('    iR:%d lSkipDN:%r',iR,lSkipDN)
             # ----- end:get folder list to skip
+            # +++++ beg:get configuration
+            iR,sTimePrecision=self.getCfg('sTimePrecision')
+            iR,sStatNew=self.getCfg('sStatNew',oDft=0)
+            iR,sStatMod=self.getCfg('sStatMod',oDft=0)
+            iR,sStatUse=self.getCfg('sStatUse',oDft=0)
+            # ----- end:get configuration
             # +++++ beg:walk through directory recursive
             for sRoot,lDN,lFN in os.walk(sDef):
                 #sCurDN='./'+sRoot[iSrcLen:].replace(os.sep,'/')
@@ -257,7 +267,12 @@ class ldmStorageFolder(ldmStorage):
                 if dFN is not None:
                     for sFN in lFN:
                         iR,oRef=self.getRef()
-                        iR,dStat=self.getStat(sRoot,sFN,oRef,**kwargs)
+                        iR,dStat=self.getStat(sRoot,sFN,oRef,
+                                        sTimePrecision=sTimePrecision,
+                                        sStatNew=sStatNew,
+                                        sStatMod=sStatMod,
+                                        sStatUse=sStatUse,
+                                        **kwargs)
                         if iR>0:
                             if self.iVerbose>0:
                                 self.logDbg('          sFN:%s dStat:%r',sFN,dStat)
@@ -435,6 +450,28 @@ class ldmStorageFolder(ldmStorage):
             return -1
     def getStatDct(self,sFN,oStat,dStat,oRef,**kwargs):
         return 0
+    def getStatTimeStamp(self,sFN,oStat,dStat,oRef,
+                    sTimePrecision='minutes',
+                    sStatNew=0,
+                    sStatMod=0,
+                    sStatUse=0,
+                    **kwargs):
+        try:
+            iRet=0
+            if sStatNew:
+                oTmp=dt.fromtimestamp(oStat.st_ctime)
+                dStat[sStatNew]=oTmp.isoformat(timespec=sTimePrecision)
+                iRet+=1
+            if sStatMod:
+                oTmp=dt.fromtimestamp(oStat.st_mtime)
+                dStat[sStatMod]=oTmp.isoformat(timespec=sTimePrecision)
+            if sStatUse:
+                oAccess=dt.fromtimestamp(oStat.st_atime)
+                dStat[sStatUse]=oTmp.isoformat(timespec=sTimePrecision)
+            return iRet
+        except:
+            self.logTB()
+        return 0
     def getStat(self,sDN,sFN,oRef,**kwargs):
         try:
             if sDN is not None:
@@ -449,6 +486,7 @@ class ldmStorageFolder(ldmStorage):
                 dStat={
                     'sz':oStat.st_size,
                 }
+                iR=self.getStatTimeStamp(sTmpFN,oStat,dStat,oRef,**kwargs)
                 iR=self.getStatDct(sTmpFN,oStat,dStat,oRef,**kwargs)
                 return 1,dStat
             return 0,None
